# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'Kind',
]


class Kind(str, Enum):
    """
    The kind of workbook. Choices are user and shared.
    """
    USER = "user"
    SHARED = "shared"
