# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from ._enums import *
from .database import *
from .firewall_rule import *
from .get_database import *
from .get_firewall_rule import *
from .get_linked_server import *
from .get_patch_schedule import *
from .get_private_endpoint_connection import *
from .get_redis import *
from .get_redis_enterprise import *
from .linked_server import *
from .list_database_keys import *
from .list_redis_keys import *
from .patch_schedule import *
from .private_endpoint_connection import *
from .redis import *
from .redis_enterprise import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_azure_native.cache.v20150801 as __v20150801
    v20150801 = __v20150801
    import pulumi_azure_native.cache.v20160401 as __v20160401
    v20160401 = __v20160401
    import pulumi_azure_native.cache.v20170201 as __v20170201
    v20170201 = __v20170201
    import pulumi_azure_native.cache.v20171001 as __v20171001
    v20171001 = __v20171001
    import pulumi_azure_native.cache.v20180301 as __v20180301
    v20180301 = __v20180301
    import pulumi_azure_native.cache.v20190701 as __v20190701
    v20190701 = __v20190701
    import pulumi_azure_native.cache.v20200601 as __v20200601
    v20200601 = __v20200601
    import pulumi_azure_native.cache.v20201001preview as __v20201001preview
    v20201001preview = __v20201001preview
    import pulumi_azure_native.cache.v20201201 as __v20201201
    v20201201 = __v20201201
    import pulumi_azure_native.cache.v20210201preview as __v20210201preview
    v20210201preview = __v20210201preview
    import pulumi_azure_native.cache.v20210301 as __v20210301
    v20210301 = __v20210301
    import pulumi_azure_native.cache.v20210601 as __v20210601
    v20210601 = __v20210601
    import pulumi_azure_native.cache.v20210801 as __v20210801
    v20210801 = __v20210801
    import pulumi_azure_native.cache.v20220101 as __v20220101
    v20220101 = __v20220101
else:
    v20150801 = _utilities.lazy_import('pulumi_azure_native.cache.v20150801')
    v20160401 = _utilities.lazy_import('pulumi_azure_native.cache.v20160401')
    v20170201 = _utilities.lazy_import('pulumi_azure_native.cache.v20170201')
    v20171001 = _utilities.lazy_import('pulumi_azure_native.cache.v20171001')
    v20180301 = _utilities.lazy_import('pulumi_azure_native.cache.v20180301')
    v20190701 = _utilities.lazy_import('pulumi_azure_native.cache.v20190701')
    v20200601 = _utilities.lazy_import('pulumi_azure_native.cache.v20200601')
    v20201001preview = _utilities.lazy_import('pulumi_azure_native.cache.v20201001preview')
    v20201201 = _utilities.lazy_import('pulumi_azure_native.cache.v20201201')
    v20210201preview = _utilities.lazy_import('pulumi_azure_native.cache.v20210201preview')
    v20210301 = _utilities.lazy_import('pulumi_azure_native.cache.v20210301')
    v20210601 = _utilities.lazy_import('pulumi_azure_native.cache.v20210601')
    v20210801 = _utilities.lazy_import('pulumi_azure_native.cache.v20210801')
    v20220101 = _utilities.lazy_import('pulumi_azure_native.cache.v20220101')

