# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .get_management_association import *
from .get_management_configuration import *
from .get_solution import *
from .management_association import *
from .management_configuration import *
from .solution import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_azure_native.operationsmanagement.v20151101preview as __v20151101preview
    v20151101preview = __v20151101preview
else:
    v20151101preview = _utilities.lazy_import('pulumi_azure_native.operationsmanagement.v20151101preview')

