# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from ._enums import *
from .environment import *
from .environment_setting import *
from .gallery_image import *
from .get_environment import *
from .get_environment_setting import *
from .get_gallery_image import *
from .get_global_user_environment import *
from .get_global_user_operation_batch_status import *
from .get_global_user_operation_status import *
from .get_global_user_personal_preferences import *
from .get_lab import *
from .get_lab_account import *
from .get_lab_account_regional_availability import *
from .get_lab_plan import *
from .get_schedule import *
from .get_user import *
from .lab import *
from .lab_account import *
from .lab_plan import *
from .list_global_user_environments import *
from .list_global_user_labs import *
from .schedule import *
from .user import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_azure_native.labservices.v20181015 as __v20181015
    v20181015 = __v20181015
    import pulumi_azure_native.labservices.v20211001preview as __v20211001preview
    v20211001preview = __v20211001preview
    import pulumi_azure_native.labservices.v20211115preview as __v20211115preview
    v20211115preview = __v20211115preview
else:
    v20181015 = _utilities.lazy_import('pulumi_azure_native.labservices.v20181015')
    v20211001preview = _utilities.lazy_import('pulumi_azure_native.labservices.v20211001preview')
    v20211115preview = _utilities.lazy_import('pulumi_azure_native.labservices.v20211115preview')

